@@ -7,7 +7,7 @@ use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Base';
 
-our $VERSION = '1.17';
+our $VERSION = '1.171';
 
 has spec          => ( fix_arg=> 1 );
 has path          => ( fix_arg=> 1 );
@@ -45,10 +45,10 @@ sub emit {
     my $perl = "";
     $perl .= $fixer->emit_declare_vars($current_value, "[]");
     $perl .=<<EOF;
-if (my ${result} = ${marc}->marc_spec(
+if (defined(my ${result} = ${marc}->marc_spec(
             ${var},
             ${marc_spec},
-            ${marc_opt}) ) {
+            ${marc_opt})) ) {
     ${result} = ref(${result}) ? ${result} : [${result}];
     for ${current_value} (\@{${result}}) {
 EOF
